#!/usr/bin/perl -w

# Copyright 2022 Kevin Ryde

# This file is part of OEIS-data.
#
# OEIS-data is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 3, or (at your option) any later
# version.
#
# OEIS-data is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with OEIS-data.  If not, see <http://www.gnu.org/licenses/>.


use 5.006;
use strict;
use warnings;
use File::Spec;
use File::HomeDir;
use FindBin;
use Math::OEIS;
use Test::More tests => 1;
BEGIN { $|=1; }

# uncomment this to run the ### lines
# use Smart::Comments;

my $testsdir;
BEGIN {
  $testsdir = File::Spec->catdir($FindBin::Bin,
                                 File::Spec->updir,
                                 'tests');
}
### $testsdir
use lib $testsdir;
use MyTestHelpers;
# BEGIN { MyTestHelpers::nowarnings() }

# ../OEIS-data-reader
my $OEIS_data_reader_script
  = File::Spec->catfile($testsdir,
                        File::Spec->updir,
                        'OEIS-data-reader');
### $OEIS_data_reader_script

our ($anum,$action,$flag);
our ($internal_basename,$internal_filename);
sub action__noop { }
@ARGV = ('--anum',   'A000000',
         '--action', 'noop',
         '--flag',   '123');
do $OEIS_data_reader_script;

#------------------------------------------------------------------------------
# Read all of ~/OEIS/*.internal.txt

{
  my $good = 0;
  my $bad = 0;
  my $glob = File::Spec->catfile(File::HomeDir->my_home,
                                 'OEIS',
                                 '*.internal.txt');
  foreach my $filename (glob($glob)) {
    (my $volume,my $directories, $internal_basename)
      = File::Spec->splitpath($filename);
    $internal_basename =~ /^(A\d+)\./ or die $filename;
    $anum = $1;
    $internal_filename = $filename;
    my $data = internal_data();
    ### $data
    if (defined $data) {
      $good++;
    } else {
      $bad++;
    }
  }
  is ($bad, 0);
  diag "$good .internal.txt files parsed";
}

#-----------------------------------------------------------------------------

# Local variables:
# compile-command: "perl -w data-reader-slow.t"
# End:
